<script setup>
import { Link, useForm } from "@inertiajs/vue3";
import AuthenticationCard from "@/Components/Cards/AuthenticationCard.vue";
import AuthenticationCardLogo from "@/Components/Logos/AuthenticationCardLogo.vue";
import Checkbox from "@/Components/Forms/Checkbox.vue";
import InputError from "@/Components/Forms/InputError.vue";
import InputLabel from "@/Components/Forms/InputLabel.vue";
import TextInput from "@/Components/Forms/TextInput.vue";
import GuestsLayout from "@/Layouts/GuestsLayout.vue";
import SubmitButton from "@/Components/Buttons/SubmitButton.vue";
import EmptySectionBorder from "@/Components/Sections/EmptySectionBorder.vue";

const form = useForm({
    first_name: "",
    last_name: "",
    email: "",
    password: "",
    password_confirmation: "",
    terms: false,
});

// const submit = () => {
//     form.post(route("register"), {
//         // error bag validation
//         errorBag: "createUser",
//         preserveScroll: true,
//         onSuccess: (log) => {
//             form.reset();
//         },
//         onError: (err) => {},
//         onFinish: () => {
//             // form.reset("password", "password_confirmation");
//         },
//     });
// };
</script>

<template>
    <div
        class="bg-[url('https://images.unsplash.com/photo-1661956602116-aa6865609028?ixlib=rb-4.0.3&ixid=M3wxMjA3fDF8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=1364&q=80')] w-full min-h-screen bg-cover"
    >
        <GuestsLayout>
            <div>
                <AuthenticationCard :css="'opacity-100'">
                    <form @submit.prevent="submit">
                        <div class="mt-4 mb-8">
                            <h1 class="mySecondaryHeader text-center">
                                Upload Bukti Transfer
                            </h1>
                        </div>
                        <div class="myInputGroup">
                            <InputLabel for="nominal_donasi" value="Nominal Donasi" />
                            <TextInput
                                id="nominal_donasi"
                                v-model="form.donasi"
                                type="nominal_donasi"
                                autofocus
                                autocomplete="nominal_donasi"
                            />
                            <InputError :message="form.errors.donasi" />
                        </div>
                        <div class="myInputGroup">
                            <InputLabel for="nama_lengkap" value="Nama Pengirim" />
                            <TextInput
                                id="nama_lengkap"
                                v-model="form.email"
                                type="nama_lengkap"
                                autofocus
                                autocomplete="nama_lengkap"
                            />
                            <InputError :message="form.errors.nama_lengkap" />
                        </div>
                        <div class="myInputGroup">
                            <InputLabel for="telepon" value="Telepon/Wa." />
                            <TextInput
                                id="telepon"
                                v-model="form.telepon"
                                type="telepon"
                                autofocus
                                autocomplete="telepon"
                            />
                            <InputError :message="form.errors.email" />
                        </div>
                        <div class="col-span-full">
                            <label
                                class="block text-sm font-normal leading-6 text-gray-900"
                                >Manage or upload new images
                            </label>
                            <div
                                class="mt-2 mb-6 flex justify-center rounded-lg border border-dashed border-gray-900/25 px-6 py-10"
                            >
                                <div class="text-center">
                                    <svg
                                        class="mx-auto h-12 w-12 text-gray-400"
                                        fill="none"
                                        viewBox="0 0 24 24"
                                        stroke="currentColor"
                                        aria-hidden="true"
                                    >
                                        <path
                                            vector-effect="non-scaling-stroke"
                                            stroke-linecap="round"
                                            stroke-linejoin="round"
                                            stroke-width="2"
                                            d="M9 13h6m-3-3v6m-9 1V7a2 2 0 012-2h6l2 2h6a2 2 0 012 2v8a2 2 0 01-2 2H5a2 2 0 01-2-2z"
                                        />
                                    </svg>
                                    <div
                                        class="mt-4 flex text-sm leading-6 text-gray-600"
                                    >
                                        <PrimaryButton
                                            @click="handleMediaLibrary"
                                            class="mb-4 myPrimaryButton gap-2 items-center"
                                        >
                                            <svg
                                                xmlns="http://www.w3.org/2000/svg"
                                                fill="none"
                                                viewBox="0 0 24 24"
                                                stroke-width="1.5"
                                                stroke="currentColor"
                                                class="w-4 h-4"
                                            >
                                                <path
                                                    stroke-linecap="round"
                                                    stroke-linejoin="round"
                                                    d="M2.25 15.75l5.159-5.159a2.25 2.25 0 013.182 0l5.159 5.159m-1.5-1.5l1.409-1.409a2.25 2.25 0 013.182 0l2.909 2.909m-18 3.75h16.5a1.5 1.5 0 001.5-1.5V6a1.5 1.5 0 00-1.5-1.5H3.75A1.5 1.5 0 002.25 6v12a1.5 1.5 0 001.5 1.5zm10.5-11.25h.008v.008h-.008V8.25zm.375 0a.375.375 0 11-.75 0 .375.375 0 01.75 0z"
                                                ></path>
                                            </svg>
                                            Manage & Upload
                                        </PrimaryButton>
                                    </div>
                                    <p class="text-xs leading-5 text-gray-600">
                                        PNG, JPG, GIF up to 2MB per file.
                                    </p>
                                </div>
                            </div>
                        </div>
                        <div class="flex items-center justify-between mt-4">
                            <a href="https://wa.me/085609074669/?text=teksberkodeurl">
                                <SubmitButton
                                    :disabled="form.processing"
                                    buttonText="Chat Whatsapp"
                                >
                                </SubmitButton>
                            </a>

                            <a href="/pdfviewer">
                                <SubmitButton
                                    :disabled="form.processing"
                                    buttonText="Kirim"
                                >
                                </SubmitButton>
                            </a>
                        </div>
                    </form>
                </AuthenticationCard>
            </div>
            <EmptySectionBorder></EmptySectionBorder>
        </GuestsLayout>
    </div>
</template>
